@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.c,v 1.39 2005/11/08 13:10:09 chpe Exp $
+ *  $Id: ephy-embed-single.c,v 1.42 2006/01/29 21:09:52 crispin Exp $
  */
 
 #include "config.h"
@@ -145,33 +145,6 @@ ephy_embed_single_iface_init (gpointer g_iface)
 		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
 		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
 
-/**
- * EphyEmbedSingle::check_content:
- * @single: the #EphyEmbedSingle
- * @type: the type of content (an #EphyContentCheckType)
- * @address: the address of the content
- * @requesting_address: the address of the requesting content (may be empty)
- * @mime_type_guess: a guess of the mime type of the content (may be empty)
- *
- * The ::check-content signal is emitted when Epiphany loads any content from
- * anywhere.
- *
- * If a connected callback returns %TRUE, the
- * signal emission will stop, and the load be aborted.
- **/
-	g_signal_new ("check_content",
-		      EPHY_TYPE_EMBED_SINGLE,
-		      G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
-		      G_STRUCT_OFFSET (EphyEmbedSingleIface, check_content),
-		      g_signal_accumulator_true_handled, NULL,
-		      ephy_marshal_BOOLEAN__ENUM_STRING_STRING_STRING,
-		      G_TYPE_BOOLEAN,
-		      4,
-		      EPHY_TYPE_CONTENT_CHECK_TYPE,
-		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
-		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
-		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
-
 /**
  * EphyEmbedSingle::network-status:
  * 
@@ -189,6 +162,20 @@ ephy_embed_single_iface_init (gpointer g_iface)
 	}
 }
 
+/**
+ * ephy_embed_single_init:
+ * @single: the #EphyEmbedSingle
+ * 
+ * Performs startup initialisations. Must be called before calling
+ * any other methods.
+ **/
+gboolean
+ephy_embed_single_init (EphyEmbedSingle *single)
+{
+	EphyEmbedSingleIface *iface = EPHY_EMBED_SINGLE_GET_IFACE (single);
+	return iface->init (single);
+}
+
 /**
  * ephy_embed_single_clear_cache:
  * @single: the #EphyEmbedSingle
@@ -302,3 +289,20 @@ ephy_embed_single_open_window (EphyEmbedSingle *single,
 	EphyEmbedSingleIface *iface = EPHY_EMBED_SINGLE_GET_IFACE (single);
 	return iface->open_window (single, parent, address, name, features);
 }
+
+/**
+ * ephy_embed_single_get_backend_name
+ * @single: the #EphyEmbedSingle
+ *
+ * Can be used to find the particular backend that is being used
+ * for rendering pages.
+ * 
+ * Returns: the name of the backend. Valid returns are "gecko-1.7", 
+ * "gecko-1.8" and "gecko-1.9"
+ */
+const char *
+ephy_embed_single_get_backend_name (EphyEmbedSingle *single)
+{
+	EphyEmbedSingleIface *iface = EPHY_EMBED_SINGLE_GET_IFACE (single);
+	return iface->get_backend_name (single);
+}
