@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyUtils.cpp,v 1.17 2006/01/17 13:58:19 chpe Exp $
+ *  $Id: EphyUtils.cpp,v 1.17.2.1 2006/05/15 18:32:49 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -254,7 +254,7 @@ EphyUtils::CollatePrintSettings (EmbedPrintInfo *info,
 		const char *temp_dir;
 		
 		temp_dir = ephy_file_tmp_dir ();
-		base = g_build_filename (temp_dir, "printXXXXXX", NULL);
+		base = g_build_filename (temp_dir, "printXXXXXX", (char *) NULL);
 		info->tempfile = ephy_file_tmp_filename (base, "ps");
 		g_free (base);
 		
