@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: FilePicker.cpp,v 1.52.4.1 2005/09/28 13:29:40 chpe Exp $
+ *  $Id: FilePicker.cpp,v 1.55.2.1 2006/05/15 18:32:49 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -25,6 +25,7 @@
 
 #include "FilePicker.h"
 #include "EphyUtils.h"
+#include "AutoJSContextStack.h"
 
 #include <nsCOMPtr.h>
 #undef MOZILLA_INTERNAL_API
@@ -127,6 +128,10 @@ NS_IMETHODIMP GFilePicker::Init(nsIDOMWindowInternal *parent, const PRUnichar *t
 	{
 		gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (mDialog), TRUE);
 	}
+	if (mMode == nsIFilePicker::modeSave)
+	{
+		gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (mDialog), TRUE);
+	}
 
 	g_object_add_weak_pointer (G_OBJECT (mDialog), (gpointer *) &mDialog);
 
@@ -146,7 +151,7 @@ NS_IMETHODIMP GFilePicker::AppendFilters(PRInt32 filterMask)
 	if (filterMask & nsIFilePicker::filterAll)
 	{
 		ephy_file_chooser_add_pattern_filter (mDialog, _("All files"),
-						      "*", NULL);
+						      "*", (char*) NULL);
 	}
 	if (filterMask & nsIFilePicker::filterHTML)
 	{
@@ -154,7 +159,7 @@ NS_IMETHODIMP GFilePicker::AppendFilters(PRInt32 filterMask)
 						   "text/html",
 						   "application/xhtml+xml",
 						   "text/xml",
-						   NULL);
+						   (char *) NULL);
 	}
 	if (filterMask & nsIFilePicker::filterText)
 	{
@@ -167,17 +172,17 @@ NS_IMETHODIMP GFilePicker::AppendFilters(PRInt32 filterMask)
 						   "image/png",
 						   "image/jpeg",
 						   "image/gif",
-						   NULL);
+						   (char *) NULL);
 	}
 	if (filterMask & nsIFilePicker::filterXML)
 	{
 		ephy_file_chooser_add_pattern_filter (mDialog, _("XML files"),
-						      "*.xml", NULL);
+						      "*.xml", (char *) NULL);
 	}
 	if (filterMask & nsIFilePicker::filterXUL)
 	{
 		ephy_file_chooser_add_pattern_filter (mDialog, _("XUL files"),
-						      "*.xul", NULL);
+						      "*.xul", (char *) NULL);
 	}
 
 	return NS_OK;
@@ -357,7 +362,7 @@ NS_IMETHODIMP GFilePicker::SetDisplayDirectory(nsILocalFile *aDisplayDirectory)
 		NS_UTF16ToCString (mDefaultString, NS_CSTRING_ENCODING_NATIVE_FILESYSTEM,
 				   defaultString);
 
-		char *filename = g_build_filename (dir.get(), defaultString.get(), NULL);
+		char *filename = g_build_filename (dir.get(), defaultString.get(), (char *) NULL);
 		LOG ("Setting filename to %s", filename);
 		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (mDialog), filename);
 		g_free (filename);
@@ -426,6 +431,11 @@ NS_IMETHODIMP GFilePicker::GetFiles(nsISimpleEnumerator * *aFiles)
 /* short show (); */
 NS_IMETHODIMP GFilePicker::Show(PRInt16 *_retval)
 {
+	nsresult rv;
+	AutoJSContextStack stack;
+	rv = stack.Init ();
+	if (NS_FAILED (rv)) return rv;
+
 	LOG ("GFilePicker::Show");
 
 	gtk_window_set_modal (GTK_WINDOW (mDialog), TRUE);
@@ -462,7 +472,7 @@ NS_IMETHODIMP GFilePicker::Show(PRInt16 *_retval)
 	}
 	while (response == GTK_RESPONSE_ACCEPT &&
 	       mMode == nsIFilePicker::modeSave &&
-	       !ephy_gui_confirm_overwrite_file (GTK_WIDGET (mDialog), filename));
+	       !ephy_gui_check_location_writable (GTK_WIDGET (mDialog), filename));
 
 	gtk_widget_hide (GTK_WIDGET (mDialog));
 
