@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-persist.cpp,v 1.46.2.2 2005/04/18 19:04:24 chpe Exp $
+ *  $Id: mozilla-embed-persist.cpp,v 1.55.6.1 2006/05/15 18:32:49 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -30,6 +30,7 @@
 #include "EphyHeaderSniffer.h"
 #include "MozDownload.h"
 #include "EphyUtils.h"
+#include "ephy-debug.h"
 
 #include <stddef.h>
 
@@ -40,6 +41,10 @@
 #include <nsIDOMSerializer.h>
 #include <nsIIOService.h>
 #include <nsNetCID.h>
+#include <nsNetError.h>
+#include <nsICacheEntryDescriptor.h>
+#include <nsICacheService.h>
+#include <nsICacheSession.h>
 
 static void
 mozilla_embed_persist_class_init (MozillaEmbedPersistClass *klass);
@@ -122,10 +127,18 @@ impl_cancel (EphyEmbedPersist *persist)
 {
 	nsCOMPtr<nsIWebBrowserPersist> bpersist =
 		MOZILLA_EMBED_PERSIST (persist)->priv->mPersist;
+#ifdef HAVE_GECKO_1_8
+	nsCOMPtr<nsICancelable> cancelable (do_QueryInterface (bpersist));
+	if (cancelable)
+	{
+		cancelable->Cancel (NS_BINDING_ABORTED);
+	}
+#else
 	if (bpersist)
 	{
 		bpersist->CancelSave ();
 	}
+#endif
 
 	g_object_unref (persist);
 }
@@ -151,7 +164,7 @@ impl_save (EphyEmbedPersist *persist)
 		      "flags", &flags,
 		      "embed", &embed,
 		      "max_size", &max_size,
-		      NULL);
+		      (char *) NULL);
 
 	g_return_val_if_fail (!(flags & EPHY_EMBED_PERSIST_COPY_PAGE)
 			      || embed != NULL, FALSE);	
@@ -168,37 +181,23 @@ impl_save (EphyEmbedPersist *persist)
 	/* we must have one of uri or browser */
 	g_assert (browser != NULL || uri != NULL);
 
-	/* Get a temp filename to save to */
-	char *tmp_filename, *base;
-	base = g_build_filename (g_get_tmp_dir (), "sav-XXXXXX", NULL);
-	tmp_filename = ephy_file_tmp_filename (base, "html");
-	g_free (base);
-	if (tmp_filename == NULL) return FALSE;
-
-	nsCOMPtr<nsILocalFile> tmpFile = do_CreateInstance (NS_LOCAL_FILE_CONTRACTID);
-	NS_ENSURE_TRUE (tmpFile, FALSE);
-
-	tmpFile->InitWithNativePath (nsEmbedCString (tmp_filename));
-	g_free (tmp_filename);
-
 	/* Get the uri to save to */
 	nsCOMPtr<nsIURI> inURI;
-	nsEmbedCString sURI;
 	if (uri)
 	{
-		sURI.Assign (uri);
+		/* FIXME: origin charset!! */
+		rv = EphyUtils::NewURI (getter_AddRefs(inURI), nsEmbedCString(uri));
+		NS_ENSURE_SUCCESS (rv, FALSE);
 	}
 	else
 	{
-		rv = browser->GetDocumentUrl (sURI);
+		rv = browser->GetDocumentURI (getter_AddRefs (inURI));
 		NS_ENSURE_SUCCESS (rv, FALSE);
 	}
 
-	rv = EphyUtils::NewURI (getter_AddRefs(inURI), sURI);
-	NS_ENSURE_SUCCESS (rv, FALSE);
-
 	/* Get post data */
 	nsCOMPtr<nsIInputStream> postData;
+	/* FIXME: don't do this on COPY_PAGE to ensure we don't end up reposting? */
 	if (browser)
 	{
 		PRInt32 sindex;
@@ -233,20 +232,79 @@ impl_save (EphyEmbedPersist *persist)
 
 
 	/* Get the current page descriptor */
-	nsCOMPtr<nsISupports> pageDescriptor;
+	nsCOMPtr<nsISupports> cacheDescriptor;
 	if (browser)
 	{
-	        browser->GetPageDescriptor(getter_AddRefs(pageDescriptor));
+	        browser->GetPageDescriptor(getter_AddRefs (cacheDescriptor));
 	}
 
+	/* Try to get a descriptor from the cache session */
+	/* FIXME: what about https?? */
+	PRBool isHttp = PR_FALSE, isHttps = PR_FALSE;
+	if (!cacheDescriptor &&
+	    (flags & EPHY_EMBED_PERSIST_FROM_CACHE) &&
+	    inURI &&
+	    ((NS_SUCCEEDED (inURI->SchemeIs ("http", &isHttp)) && isHttp) ||
+	     (NS_SUCCEEDED (inURI->SchemeIs ("https", &isHttps)) && isHttps )))
+	{
+		nsCOMPtr<nsICacheService> cacheService
+				(do_GetService(NS_CACHESERVICE_CONTRACTID));
+		if (cacheService)
+		{
+			nsCOMPtr<nsICacheSession> cacheSession;
+			rv = cacheService->CreateSession ("HTTP",
+							  nsICache::STORE_ANYWHERE,
+							  PR_TRUE,
+							  getter_AddRefs (cacheSession));
+			if (NS_SUCCEEDED (rv) && cacheSession)
+			{
+				nsCOMPtr<nsICacheEntryDescriptor> descriptor;
+
+				nsEmbedCString spec;
+				inURI->GetSpec (spec);
+
+#ifdef HAVE_GECKO_1_8
+				rv = cacheSession->OpenCacheEntry
+					(spec,
+					 nsICache::ACCESS_READ,
+					 PR_FALSE, getter_AddRefs (descriptor));
+#else
+				rv = cacheSession->OpenCacheEntry
+					(spec.get(),
+					 nsICache::ACCESS_READ,
+					 PR_FALSE, getter_AddRefs (descriptor));
+#endif
+
+				cacheDescriptor = do_QueryInterface (descriptor);
+
+				LOG ("Getting cache descriptor for '%s' rv=%x", spec.get(), rv);
+			}
+		}
+	}
+
+	LOG ("Cache descriptor %p", cacheDescriptor.get());
+
 	/* if we have COPY_PAGE, we *need* to have a page descriptor, else we'll re-fetch
 	 * the page, which will possibly give a different page than the original which we
 	 * need for view source
 	 */
-	NS_ENSURE_TRUE (!(flags & EPHY_EMBED_PERSIST_COPY_PAGE) || pageDescriptor, FALSE);
+	NS_ENSURE_TRUE (!(flags & EPHY_EMBED_PERSIST_COPY_PAGE) || cacheDescriptor, FALSE);
 
-	if (filename == NULL)
+	if (filename == NULL || filename[0] == '\0')
 	{
+		/* Get a temp filename to save to */
+		char *tmp_filename, *base;
+		base = g_build_filename (g_get_tmp_dir (), "sav-XXXXXX", (char *) NULL);
+		tmp_filename = ephy_file_tmp_filename (base, "html");
+		g_free (base);
+		if (tmp_filename == NULL) return FALSE;
+
+		nsCOMPtr<nsILocalFile> tmpFile = do_CreateInstance (NS_LOCAL_FILE_CONTRACTID);
+		NS_ENSURE_TRUE (tmpFile, FALSE);
+
+		tmpFile->InitWithNativePath (nsEmbedCString (tmp_filename));
+		g_free (tmp_filename);
+
 		/* Create an header sniffer and do the save */
 		nsCOMPtr<nsIWebBrowserPersist> webPersist =
 			MOZILLA_EMBED_PERSIST (persist)->priv->mPersist;
@@ -256,9 +314,9 @@ impl_save (EphyEmbedPersist *persist)
 			(webPersist, MOZILLA_EMBED_PERSIST (persist),
 			 tmpFile, inURI, DOMDocument, postData, single);
 		if (!sniffer) return FALSE;
- 
+
 		webPersist->SetProgressListener(sniffer);
-		rv = webPersist->SaveURI(inURI, pageDescriptor, nsnull, nsnull, nsnull, tmpFile);
+		rv = webPersist->SaveURI(inURI, cacheDescriptor, nsnull /* FIXME: Referrer */, nsnull, nsnull, tmpFile);
 		if (NS_FAILED (rv)) return FALSE;
 	}
 	else
@@ -271,7 +329,7 @@ impl_save (EphyEmbedPersist *persist)
 
 		rv =  InitiateMozillaDownload (DOMDocument, inURI, destFile,
 					       nsnull, inURI, MOZILLA_EMBED_PERSIST (persist),
-					       postData, pageDescriptor, max_size);
+					       postData, cacheDescriptor, max_size);
 		if (NS_FAILED (rv)) return FALSE;
 	}
 
@@ -295,12 +353,12 @@ impl_to_string (EphyEmbedPersist *persist)
 	g_object_get (persist,
 	              "flags", &flags,
 	              "embed", &embed,
-	              NULL);
+	              (char *) NULL);
 	g_object_unref (persist);
-	g_assert (embed != NULL);
+	g_return_val_if_fail (embed != NULL, NULL);
 
 	browser = (EphyBrowser *) _mozilla_embed_get_ephy_browser (MOZILLA_EMBED(embed));
-	g_assert (browser != NULL);
+	g_return_val_if_fail (browser != NULL, NULL);
 
 	if (flags & EPHY_EMBED_PERSIST_MAINDOC)
 	{
@@ -310,20 +368,23 @@ impl_to_string (EphyEmbedPersist *persist)
 	{
 		rv = browser->GetTargetDocument (getter_AddRefs(DOMDocument));
 	}
-	if (NS_FAILED(rv) || !DOMDocument) return NULL;
-
-	nsCOMPtr<nsIDOMNode> node = do_QueryInterface(DOMDocument);
-	if (!node) return NULL;
-
-	nsCOMPtr<nsIDOMSerializer> serializer;
-	serializer = do_CreateInstance(NS_XMLSERIALIZER_CONTRACTID, &rv);
-	NS_ENSURE_SUCCESS (rv, FALSE);
-
-	nsEmbedString outString;
-	serializer->SerializeToString(node, outString);
 
 	nsEmbedCString cOutString;
-	NS_UTF16ToCString (outString, NS_CSTRING_ENCODING_UTF8, cOutString);
+	nsCOMPtr<nsIDOMNode> node = do_QueryInterface(DOMDocument);
+	if (node)
+	{
+		nsEmbedString outString;
+		nsCOMPtr<nsIDOMSerializer> serializer;
+		serializer = do_CreateInstance(NS_XMLSERIALIZER_CONTRACTID, &rv);
+		if (serializer)
+		{
+			serializer->SerializeToString(node, outString);
+
+			NS_UTF16ToCString (outString, NS_CSTRING_ENCODING_UTF8, cOutString);
+		}
+	}
+
+	g_object_unref (embed);
 
 	return g_strdup (cOutString.get());
 }
@@ -332,7 +393,7 @@ static GObject *
 mozilla_embed_persist_constructor (GType type, guint n_construct_properties,
 			           GObjectConstructParam *construct_params)
 {
-	/* we depend on single because of mozilla initialization */
+	/* this will ensure that mozilla is started up */
 	ephy_embed_shell_get_embed_single (embed_shell);
 
 	return parent_class->constructor (type, n_construct_properties,
