@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ppview-toolbar.c,v 1.28 2005/01/05 20:09:09 chpe Exp $
+ *  $Id: ppview-toolbar.c,v 1.31 2005/11/08 12:56:23 chpe Exp $
  */
 
 #include "config.h"
@@ -84,7 +84,7 @@ static void
 toolbar_cmd_ppv_close (GtkUIManager *merge,
 		       PPViewToolbar *t);
 
-static GtkActionEntry entries [] = {
+static const GtkActionEntry entries [] = {
 	{ "PPVGotoFirst", GTK_STOCK_GOTO_FIRST,
 	  N_("First"), NULL,
 	  N_("Go to the first page"),
@@ -109,13 +109,13 @@ static GtkActionEntry entries [] = {
 
 static const char ui_info[] =
 "<ui>"
-"  <toolbar name=\"PPViewToolbar\">"
-"    <toolitem name=\"PPVGotoFirstItem\" action=\"PPVGotoFirst\" />"
-"    <toolitem name=\"PPVGotoLastItem\" action=\"PPVGotoLast\" />"
-"    <toolitem name=\"PPVGoBackItem\" action=\"PPVGoBack\" />"
-"    <toolitem name=\"PPVGoForwardItem\" action=\"PPVGoForward\" />"
-"    <toolitem name=\"PPVCloseItem\" action=\"PPVClose\" />"
-"  </toolbar>\n"
+"<toolbar name=\"PPViewToolbar\">"
+"<toolitem name=\"PPVGotoFirstItem\" action=\"PPVGotoFirst\" />"
+"<toolitem name=\"PPVGotoLastItem\" action=\"PPVGotoLast\" />"
+"<toolitem name=\"PPVGoBackItem\" action=\"PPVGoBack\" />"
+"<toolitem name=\"PPVGoForwardItem\" action=\"PPVGoForward\" />"
+"<toolitem name=\"PPVCloseItem\" action=\"PPVClose\" />"
+"</toolbar>"
 "</ui>\n";
 
 GType
@@ -164,7 +164,7 @@ ppview_toolbar_class_init (PPViewToolbarClass *klass)
                                                               "Window",
                                                               "Window",
                                                               EPHY_TYPE_WINDOW,
-							      G_PARAM_WRITABLE |
+							      G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 							      G_PARAM_CONSTRUCT_ONLY));
 
 	g_type_class_add_private (object_class, sizeof (PPViewToolbarPrivate));
@@ -212,13 +212,13 @@ toolbar_update_sensitivity (PPViewToolbar *t)
 	c_page = t->priv->current_page;
 
 	action = gtk_action_group_get_action (action_group, "PPVGoBack");
-	g_object_set (action, "sensitive", c_page > 1, NULL);
+	gtk_action_set_sensitive (action, c_page > 1);
 	action = gtk_action_group_get_action (action_group, "PPVGotoFirst");
-	g_object_set (action, "sensitive", c_page > 1, NULL);
+	gtk_action_set_sensitive (action, c_page > 1);
 	action = gtk_action_group_get_action (action_group, "PPVGoForward");
-	g_object_set (action, "sensitive", c_page < pages, NULL);
+	gtk_action_set_sensitive (action, c_page < pages);
 	action = gtk_action_group_get_action (action_group, "PPVGotoLast");
-	g_object_set (action, "sensitive", c_page < pages, NULL);
+	gtk_action_set_sensitive (action, c_page < pages);
 }
 
 static void
