@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.120 2006/01/16 23:51:41 chpe Exp $
+ *  $Id: prefs-dialog.c,v 1.123.2.1 2006/04/20 13:08:14 chpe Exp $
  */
 
 #include "config.h"
@@ -121,6 +121,7 @@ enum
 	HOMEPAGE_BLANK_PROP,
 	AUTO_OPEN_PROP,
 	DOWNLOAD_PATH_HBOX_PROP,
+	DOWNLOAD_PATH_LABEL_PROP,
 
 	/* Fonts and Colors */
 	USE_FONTS_PROP,
@@ -166,6 +167,7 @@ EphyDialogProperty properties [] =
 	{ "homepage_blank_button",		NULL,			  PT_NORMAL,	0 },
 	{ "automatic_downloads_checkbutton",	CONF_AUTO_DOWNLOADS,      PT_AUTOAPPLY,	0 },
 	{ "download_button_hbox",		NULL,			  PT_NORMAL,	0 },
+	{ "download_button_label",		NULL,			  PT_NORMAL,	0 },
 
 	/* Fonts and Colors */
 	{ "use_fonts_checkbutton",	CONF_RENDERING_USE_OWN_FONTS,	PT_AUTOAPPLY | PT_INVERTED,	0 },
@@ -268,6 +270,13 @@ enum
 	COL_ENC_CODE
 };
 
+enum
+{
+	COL_AUTODETECTOR_NAME,
+	COL_AUTODETECTOR_DATA,
+	COL_AUTODETECTOR_IS_SEP
+};
+
 #define EPHY_PREFS_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_PREFS_DIALOG, PrefsDialogPrivate))
 
 struct PrefsDialogPrivate
@@ -322,17 +331,21 @@ prefs_dialog_finalize (GObject *object)
 
 	if (priv->fonts_dialog != NULL)
 	{
+		EphyDialog **fonts_dialog = &priv->fonts_dialog;
+
 		g_object_remove_weak_pointer
 			(G_OBJECT (priv->fonts_dialog),
-			(gpointer *) &priv->fonts_dialog);
+			(gpointer *) fonts_dialog);
 		g_object_unref (priv->fonts_dialog);
 	}
 
 	if (priv->add_lang_dialog != NULL)
 	{
+		EphyDialog **add_lang_dialog = &priv->add_lang_dialog;
+
 		g_object_remove_weak_pointer
 				(G_OBJECT (priv->add_lang_dialog),
-				 (gpointer *) &priv->add_lang_dialog);
+				 (gpointer *) add_lang_dialog);
 		g_object_unref (priv->add_lang_dialog);
 	}
 
@@ -362,7 +375,7 @@ prefs_dialog_show_help (EphyDialog *dialog)
 
 	static char * const help_preferences[] = {
 		"general-preferences",
-		"fonts-and-colors-preferences",
+		"fonts-and-style-preferences",
 		"privacy-preferences",
 		"language-preferences"
 	};
@@ -483,7 +496,7 @@ font_prefs_dialog_response_cb (GtkWidget *widget,
 {
 	if (response == GTK_RESPONSE_HELP)
 	{
-		/* FIXME */
+		ephy_gui_help (GTK_WINDOW (widget), "epiphany", "fonts-and-style-preferences");
 		return;
 	}
 
@@ -495,9 +508,12 @@ row_is_separator (GtkTreeModel *model,
                   GtkTreeIter *iter,
                   gpointer data)
 {
-        gboolean is_sep;
-        gtk_tree_model_get (model, iter, COL_FONT_IS_SEP, &is_sep, -1);
-        return is_sep;
+	int column = GPOINTER_TO_INT (data);
+	gboolean is_sep;
+
+	gtk_tree_model_get (model, iter, column, &is_sep, -1);
+
+	return is_sep;
 }
 
 static EphyDialog *
@@ -554,10 +570,10 @@ setup_fonts_dialog (PrefsDialog *pd)
 
 	gtk_combo_box_set_row_separator_func (GTK_COMBO_BOX (variable_combo),
 					      (GtkTreeViewRowSeparatorFunc) row_is_separator,
-					      NULL, NULL);
+					      GINT_TO_POINTER (COL_FONT_IS_SEP), NULL);
 	gtk_combo_box_set_row_separator_func (GTK_COMBO_BOX (monospace_combo),
 					      (GtkTreeViewRowSeparatorFunc) row_is_separator,
-					      NULL, NULL);
+					      GINT_TO_POINTER (COL_FONT_IS_SEP), NULL);
 
 	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
 
@@ -606,11 +622,15 @@ font_prefs_button_clicked_cb (GtkWidget *button,
 
 	if (priv->fonts_dialog == NULL)
 	{
+		EphyDialog **fonts_dialog;
+
 		priv->fonts_dialog = setup_fonts_dialog (pd);
 
+		fonts_dialog = &priv->fonts_dialog;
+
 		g_object_add_weak_pointer
 			(G_OBJECT (priv->fonts_dialog),
-			(gpointer *) &priv->fonts_dialog);
+			(gpointer *) fonts_dialog);
 	}
 
 	ephy_dialog_show (priv->fonts_dialog);
@@ -696,6 +716,96 @@ create_node_combo (EphyDialog *dialog,
 	g_object_unref (sortmodel);
 }
 
+static void
+create_autodetectors_combo (EphyDialog *dialog,
+			    int prop,
+			    EphyEncodings *encodings,
+			    EphyNode *node,
+			    const char *key,
+			    const char *default_value)
+{
+	GtkListStore *store;
+	GtkTreeIter iter;
+	GPtrArray *children;
+	GtkComboBox *combo;
+	GtkCellRenderer *renderer;
+	char *code;
+	const char *off_title = NULL;
+	guint i;
+
+	code = eel_gconf_get_string (key);
+	if (code == NULL || ephy_encodings_get_node (encodings, code, FALSE) == NULL)
+	{
+		/* safe default */
+		eel_gconf_set_string (key, default_value);
+	}
+	g_free (code);
+
+	combo = GTK_COMBO_BOX (ephy_dialog_get_control (dialog, properties[prop].id));
+
+	store = gtk_list_store_new (3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN);
+
+	children = ephy_node_get_children (node);
+	for (i = 0; i < children->len; ++i)
+	{
+		EphyNode *kid = g_ptr_array_index (children, i);
+		const char *code, *title;
+
+		code = ephy_node_get_property_string (kid, EPHY_NODE_ENCODING_PROP_ENCODING);
+		g_return_if_fail (code != NULL);
+
+		title = ephy_node_get_property_string (kid, EPHY_NODE_ENCODING_PROP_TITLE_ELIDED);
+		if (code[0] == '\0')
+		{
+			off_title = title;
+		}
+		else
+		{	
+			gtk_list_store_insert_with_values (store, &iter, -1,
+							   COL_AUTODETECTOR_NAME, title,
+							   COL_AUTODETECTOR_DATA, code,
+							   COL_AUTODETECTOR_IS_SEP, FALSE,
+							   -1);
+		}
+	}
+
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (store),
+					      COL_AUTODETECTOR_NAME,
+					      GTK_SORT_ASCENDING);
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (store),
+					      GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID,
+					      GTK_SORT_ASCENDING);
+
+	g_assert (off_title != NULL);
+
+	gtk_list_store_insert_with_values (store, &iter, 0,
+					   COL_AUTODETECTOR_NAME, off_title,
+					   COL_AUTODETECTOR_DATA, "",
+					   COL_AUTODETECTOR_IS_SEP, FALSE,
+					   -1);
+	gtk_list_store_insert_with_values (store, &iter, 1,
+					   COL_AUTODETECTOR_NAME, NULL,
+					   COL_AUTODETECTOR_DATA, "",
+					   COL_AUTODETECTOR_IS_SEP, TRUE,
+					   -1);
+
+	gtk_combo_box_set_model (combo, GTK_TREE_MODEL (store));
+	g_object_unref (store);
+
+	gtk_combo_box_set_row_separator_func (GTK_COMBO_BOX (combo),
+					      (GtkTreeViewRowSeparatorFunc) row_is_separator,
+					      GINT_TO_POINTER (COL_AUTODETECTOR_IS_SEP), NULL);
+
+
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, TRUE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer,
+					"text", COL_AUTODETECTOR_NAME,
+					NULL);
+
+	ephy_dialog_set_data_column (dialog, properties[prop].id, COL_AUTODETECTOR_DATA);
+}
+
 static void
 language_editor_add (PrefsDialog *pd,
 		     const char *code,
@@ -1043,11 +1153,15 @@ language_editor_add_button_clicked_cb (GtkWidget *button,
 {
 	if (pd->priv->add_lang_dialog == NULL)
 	{
+		EphyDialog **add_lang_dialog;
+
 		pd->priv->add_lang_dialog = setup_add_language_dialog (pd);
 
+		add_lang_dialog = &pd->priv->add_lang_dialog;
+
 		g_object_add_weak_pointer
 			(G_OBJECT (pd->priv->add_lang_dialog),
-			(gpointer *) &pd->priv->add_lang_dialog);
+			(gpointer *) add_lang_dialog);
 	}
 
 	ephy_dialog_show (pd->priv->add_lang_dialog);
@@ -1307,7 +1421,7 @@ download_path_changed_cb (GtkFileChooser *button)
 static void
 create_download_path_button (EphyDialog *dialog)
 {
-	GtkWidget *parent, *hbox, *button;
+	GtkWidget *parent, *hbox, *label, *button;
 	EphyFileChooser *fc;
 	char *dir;
 
@@ -1315,6 +1429,7 @@ create_download_path_button (EphyDialog *dialog)
 
 	ephy_dialog_get_controls (dialog,
 				  properties[DOWNLOAD_PATH_HBOX_PROP].id, &hbox,
+				  properties[DOWNLOAD_PATH_LABEL_PROP].id, &label,
 				  properties[WINDOW_PROP].id, &parent,
 				  NULL);
 
@@ -1332,6 +1447,7 @@ create_download_path_button (EphyDialog *dialog)
 						 DOWNLOAD_BUTTON_WIDTH);
 	g_signal_connect (button, "current-folder-changed",
 			  G_CALLBACK (download_path_changed_cb), dialog);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), button);
 	gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
 	gtk_widget_show (button);
 
@@ -1484,9 +1600,9 @@ prefs_dialog_init (PrefsDialog *pd)
 	create_node_combo (dialog, DEFAULT_ENCODING_PROP, encodings,
 			   ephy_encodings_get_all (encodings),
 			   CONF_LANGUAGE_DEFAULT_ENCODING, "ISO-8859-1");
-	create_node_combo (dialog, AUTO_ENCODING_PROP, encodings,
-			   ephy_encodings_get_detectors (encodings),
-			   CONF_LANGUAGE_AUTODETECT_ENCODING, "");
+	create_autodetectors_combo (dialog, AUTO_ENCODING_PROP, encodings,
+				    ephy_encodings_get_detectors (encodings),
+				    CONF_LANGUAGE_AUTODETECT_ENCODING, "");
 
 	create_language_section	(dialog);
 
